@@ -1,19 +1,13 @@
 import copy
-
 import asyncio
 import aiohttp
 import webbrowser
-
-import logging
 import json
 from collections import OrderedDict
 
 from .exceptions import ResponseProcessException
 
 
-logger = logging.getLogger("coin32api_channels")
-
-
 class TapiocaInstantiator:
     def __init__(self, adapter_class):
         self.adapter_class = adapter_class
@@ -70,11 +64,13 @@ class TapiocaClient:
 
     def _wrap_in_tapioca(self, data, *args, **kwargs):
         request_kwargs = kwargs.pop("request_kwargs", self._request_kwargs)
+        resource = kwargs.pop("resource", self._resource)
         return TapiocaClient(
             self._instatiate_api(),
             data=data,
             api_params=self._api_params,
             request_kwargs=request_kwargs,
+            resource=resource,
             refresh_token_by_default=self._refresh_token_default,
             refresh_data=self._refresh_data,
             session=self._session,
@@ -84,11 +80,13 @@ class TapiocaClient:
 
     def _wrap_in_tapioca_executor(self, data, *args, **kwargs):
         request_kwargs = kwargs.pop("request_kwargs", self._request_kwargs)
+        resource = kwargs.pop("resource", self._resource)
         return TapiocaClientExecutor(
             self._instatiate_api(),
             data=data,
             api_params=self._api_params,
             request_kwargs=request_kwargs,
+            resource=resource,
             refresh_token_by_default=self._refresh_token_default,
             refresh_data=self._refresh_data,
             session=self._session,
@@ -238,7 +236,9 @@ class TapiocaClientExecutor(TapiocaClient):
         if name.startswith("__") and name.endswith("__"):
             raise AttributeError(name)
         if name.startswith("to_"):  # deserializing
-            return self._api._get_to_native_method(name, self._data)
+            method = self._resource.get(name)
+            kwargs = method.get("params", {}) if method else {}
+            return self._api._get_to_native_method(name, self._data, **kwargs)
         return self._wrap_in_tapioca_executor(getattr(self._data, name))
 
     def __call__(self, *args, **kwargs):
@@ -337,9 +337,9 @@ class TapiocaClientExecutor(TapiocaClient):
 
         if debug:
             response_info = "status: {} - response data: {}".format(
-                response.status, str(response.data)[:33]
+                response().status, str(response().data)[:33]
             )
-            logger.info(response_info)
+            print(response_info)
 
         return response
 
